@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     George Suaridze <suag@1c.ru> (1C-Soft LLC) - Bug 560168
  *******************************************************************************/
 package org.eclipse.help.internal.browser;
 
@@ -42,12 +43,6 @@ public class BrowserManager {
 	public static final String BROWSER_ID_FIREFOX = HelpBasePlugin.PLUGIN_ID
 	+ ".firefox"; //$NON-NLS-1$
 
-	public static final String BROWSER_ID_MOZILLA = HelpBasePlugin.PLUGIN_ID
-	+ ".mozilla"; //$NON-NLS-1$
-
-	public static final String BROWSER_ID_NETSCAPE = HelpBasePlugin.PLUGIN_ID
-			+ ".netscape"; //$NON-NLS-1$
-
 	public static final String BROWSER_ID_MAC_SYSTEM = HelpBasePlugin.PLUGIN_ID
 			+ ".defaultBrowserMacOSX"; //$NON-NLS-1$
 
@@ -100,17 +95,8 @@ public class BrowserManager {
 		if (defaultBrowserDesc == null) {
 			if (Constants.WS_WIN32.equalsIgnoreCase(os)) {
 				setDefaultBrowserID(BROWSER_ID_SYSTEM);
-			} else if (Constants.OS_AIX.equalsIgnoreCase(os)
-					|| (Constants.OS_HPUX.equalsIgnoreCase(os))
-					|| (Constants.OS_LINUX.equalsIgnoreCase(os))
-					|| (Constants.OS_SOLARIS.equalsIgnoreCase(os))) {
-				setDefaultBrowserID(BROWSER_ID_MOZILLA);
-				if (defaultBrowserDesc == null) {
-					setDefaultBrowserID(BROWSER_ID_FIREFOX);
-				}
-				if (defaultBrowserDesc == null) {
-					setDefaultBrowserID(BROWSER_ID_NETSCAPE);
-				}
+			} else if (Constants.OS_LINUX.equalsIgnoreCase(os)) {
+				setDefaultBrowserID(BROWSER_ID_FIREFOX);
 			} else if (Constants.OS_MACOSX.equalsIgnoreCase(os)) {
 				setDefaultBrowserID(BROWSER_ID_MAC_SYSTEM);
 			}
@@ -146,8 +132,8 @@ public class BrowserManager {
 
 								@Override
 								public void displayURL(String url) {
-									HelpBasePlugin
-											.logError(
+											Platform.getLog(getClass())
+													.error(
 													"There is no browser adapter configured to display " //$NON-NLS-1$
 															+ url
 															+ ".  Ensure that you have a required browser and adapter installed, and that the browser program is available on the system path.", //$NON-NLS-1$
